FetchBlobResponse

Struct FetchBlobResponse 

pub struct FetchBlobResponse {
    pub status: Option<Status>,
    pub uri: String,
    pub qualifiers: Vec<Qualifier>,
    pub expires_at: Option<Timestamp>,
    pub blob_digest: Option<Digest>,
    pub digest_function: i32,
}
A response message for [Fetch.FetchBlob][build.bazel.remote.asset.v1.Fetch.FetchBlob].

Fields

status: Option<Status>

If the status has a code other than OK, it indicates that the operation was unable to be completed for reasons outside the servers’ control. The possible fetch errors include:

  • DEADLINE_EXCEEDED: The operation could not be completed within the specified timeout.
  • NOT_FOUND: The requested asset was not found at the specified location.
  • PERMISSION_DENIED: The request was rejected by a remote server, or requested an asset from a disallowed origin.
  • ABORTED: The operation could not be completed, typically due to a failed consistency check.
  • RESOURCE_EXHAUSTED: There is insufficient quota of some resource to perform the requested operation. The client may retry after a delay.
uri: String

The uri from the request that resulted in a successful retrieval, or from which the error indicated in status was obtained.

qualifiers: Vec<Qualifier>

Any qualifiers known to the server and of interest to clients.

expires_at: Option<Timestamp>

A minimum timestamp the content is expected to be available through. Servers MAY omit this field, if not known with confidence.

blob_digest: Option<Digest>

The result of the fetch, if the status had code OK. The digest of the file’s contents, available for download through the CAS.

digest_function: i32

This field SHOULD be set to the digest function that was used by the server to compute [FetchBlobResponse.blob_digest]. Clients could use this to determine whether the server honors [FetchBlobRequest.digest_function] that was set in the request.

If unset, clients SHOULD default to use SHA256 regardless of the requested [FetchBlobRequest.digest_function].

Implementations

Source

impl FetchBlobResponse

pub fn digest_function(&self) -> Value

Returns the enum value of digest_function, or the default if the field is set to an invalid enum value.

pub fn set_digest_function(&mut self, value: Value)

Sets digest_function to the provided enum value.