ExecuteRequest

Struct ExecuteRequest 

pub struct ExecuteRequest {
    pub instance_name: String,
    pub skip_cache_lookup: bool,
    pub action_digest: Option<Digest>,
    pub execution_policy: Option<ExecutionPolicy>,
    pub results_cache_policy: Option<ResultsCachePolicy>,
    pub digest_function: i32,
    pub inline_stdout: bool,
    pub inline_stderr: bool,
    pub inline_output_files: Vec<String>,
}
A request message for [Execution.Execute][build.bazel.remote.execution.v2.Execution.Execute].

Fields

instance_name: String

The instance of the execution system to operate against. A server may support multiple instances of the execution system (with their own workers, storage, caches, etc.). The server MAY require use of this field to select between them in an implementation-defined fashion, otherwise it can be omitted.

skip_cache_lookup: bool

If true, the action will be executed even if its result is already present in the [ActionCache][build.bazel.remote.execution.v2.ActionCache]. The execution is still allowed to be merged with other in-flight executions of the same action, however - semantically, the service MUST only guarantee that the results of an execution with this field set were not visible before the corresponding execution request was sent. Note that actions from execution requests setting this field set are still eligible to be entered into the action cache upon completion, and services SHOULD overwrite any existing entries that may exist. This allows skip_cache_lookup requests to be used as a mechanism for replacing action cache entries that reference outputs no longer available or that are poisoned in any way. If false, the result may be served from the action cache.

action_digest: Option<Digest>

The digest of the [Action][build.bazel.remote.execution.v2.Action] to execute.

execution_policy: Option<ExecutionPolicy>

An optional policy for execution of the action. The server will have a default policy if this is not provided.

results_cache_policy: Option<ResultsCachePolicy>

An optional policy for the results of this execution in the remote cache. The server will have a default policy if this is not provided. This may be applied to both the ActionResult and the associated blobs.

digest_function: i32

The digest function that was used to compute the action digest.

If the digest function used is one of MD5, MURMUR3, SHA1, SHA256, SHA384, SHA512, or VSO, the client MAY leave this field unset. In that case the server SHOULD infer the digest function using the length of the action digest hash and the digest functions announced in the server’s capabilities.

inline_stdout: bool

A hint to the server to request inlining stdout in the [ActionResult][build.bazel.remote.execution.v2.ActionResult] message.

inline_stderr: bool

A hint to the server to request inlining stderr in the [ActionResult][build.bazel.remote.execution.v2.ActionResult] message.

inline_output_files: Vec<String>

A hint to the server to inline the contents of the listed output files. Each path needs to exactly match one file path in either output_paths or output_files (DEPRECATED since v2.1) in the [Command][build.bazel.remote.execution.v2.Command] message.

Implementations

Source

impl ExecuteRequest

pub fn digest_function(&self) -> Value

Returns the enum value of digest_function, or the default if the field is set to an invalid enum value.

pub fn set_digest_function(&mut self, value: Value)

Sets digest_function to the provided enum value.