pub struct OutputFile {
pub path: String,
pub digest: Option<Digest>,
pub is_executable: bool,
pub contents: Vec<u8>,
pub node_properties: Option<NodeProperties>,
}Expand description
An OutputFile is similar to a
[FileNode][build.bazel.remote.execution.v2.FileNode], but it is used as an
output in an ActionResult. It allows a full file path rather than
only a name.
Fields
path: StringThe full path of the file relative to the working directory, including the
filename. The path separator is a forward slash /. Since this is a
relative path, it MUST NOT begin with a leading forward slash.
digest: Option<Digest>The digest of the file’s content.
is_executable: boolTrue if file is executable, false otherwise.
contents: Vec<u8>The contents of the file if inlining was requested. The server SHOULD NOT inline file contents unless requested by the client in the [GetActionResultRequest][build.bazel.remote.execution.v2.GetActionResultRequest] message. The server MAY omit inlining, even if requested, and MUST do so if inlining would cause the response to exceed message size limits. Clients SHOULD NOT populate this field when uploading to the cache.
node_properties: Option<NodeProperties>Trait Implementations
Sourceimpl Clone for OutputFile
impl Clone for OutputFile
Sourcefn clone(&self) -> OutputFile
fn clone(&self) -> OutputFile
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for OutputFile
impl Debug for OutputFile
Sourceimpl Default for OutputFile
impl Default for OutputFile
Sourceimpl Message for OutputFile
impl Message for OutputFile
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.Sourceimpl PartialEq for OutputFile
impl PartialEq for OutputFile
impl StructuralPartialEq for OutputFile