pub struct SymlinkNode {
pub name: String,
pub target: String,
pub node_properties: Option<NodeProperties>,
}Expand description
A SymlinkNode represents a symbolic link.
Fields
name: StringThe name of the symlink.
target: StringThe target path of the symlink. The path separator is a forward slash /.
The target path can be relative to the parent directory of the symlink or
it can be an absolute path starting with /. Support for absolute paths
can be checked using the [Capabilities][build.bazel.remote.execution.v2.Capabilities]
API. .. components are allowed anywhere in the target path as logical
canonicalization may lead to different behavior in the presence of
directory symlinks (e.g. foo/../bar may not be the same as bar).
To reduce potential cache misses, canonicalization is still recommended
where this is possible without impacting correctness.
node_properties: Option<NodeProperties>Trait Implementations
Sourceimpl Clone for SymlinkNode
impl Clone for SymlinkNode
Sourcefn clone(&self) -> SymlinkNode
fn clone(&self) -> SymlinkNode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SymlinkNode
impl Debug for SymlinkNode
Sourceimpl Default for SymlinkNode
impl Default for SymlinkNode
Sourceimpl Message for SymlinkNode
impl Message for SymlinkNode
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SymlinkNode
impl PartialEq for SymlinkNode
impl StructuralPartialEq for SymlinkNode