UpdateActionResultRequest

Struct UpdateActionResultRequest 

pub struct UpdateActionResultRequest {
    pub instance_name: String,
    pub action_digest: Option<Digest>,
    pub action_result: Option<ActionResult>,
    pub results_cache_policy: Option<ResultsCachePolicy>,
    pub digest_function: i32,
}
A request message for [ActionCache.UpdateActionResult][build.bazel.remote.execution.v2.ActionCache.UpdateActionResult].

Fields

instance_name: String

The instance of the execution system to operate against. A server may support multiple instances of the execution system (with their own workers, storage, caches, etc.). The server MAY require use of this field to select between them in an implementation-defined fashion, otherwise it can be omitted.

action_digest: Option<Digest>

The digest of the [Action][build.bazel.remote.execution.v2.Action] whose result is being uploaded.

action_result: Option<ActionResult>

The [ActionResult][build.bazel.remote.execution.v2.ActionResult] to store in the cache.

results_cache_policy: Option<ResultsCachePolicy>

An optional policy for the results of this execution in the remote cache. The server will have a default policy if this is not provided. This may be applied to both the ActionResult and the associated blobs.

digest_function: i32

The digest function that was used to compute the action digest.

If the digest function used is one of MD5, MURMUR3, SHA1, SHA256, SHA384, SHA512, or VSO, the client MAY leave this field unset. In that case the server SHOULD infer the digest function using the length of the action digest hash and the digest functions announced in the server’s capabilities.

Implementations

Source

impl UpdateActionResultRequest

pub fn digest_function(&self) -> Value

Returns the enum value of digest_function, or the default if the field is set to an invalid enum value.

pub fn set_digest_function(&mut self, value: Value)

Sets digest_function to the provided enum value.