pub struct BotStatus {
pub bot_name: String,
pub assignments: Vec<RetryableJob>,
pub connection_timestamp: Option<Timestamp>,
}Expand description
A message describing the last-known state of a bot.
Fields
bot_name: StringThe server-assigned name for this bot.
assignments: Vec<RetryableJob>A list of RetryableJobs that this bot is currently working on, and would need to be retried or cancelled in the case of this bot failing to report back to the grid.
connection_timestamp: Option<Timestamp>The timestamp of the last time the bot was seen connecting to the grid. The BotMonitor service SHOULD use this timestamp to determine that a bot has failed to meet its next connection deadline to trigger retrying the related Jobs.